// ESP8266 example for posting data fro DHT sensor 
// to free data collection cloud ThingSpeak (https://thingspeak.com/)
// and TMEP (https://tmep.cz)
//    -- esp8266 normal (no deepsleep!) --
#include <ESP8266WiFi.h>
#include <DHT.h>

#define DHTPIN 2          // What digital pin we're connected to

// Uncomment whatever type you're using!
#define DHTTYPE DHT11     // DHT 11
//#define DHTTYPE DHT22   // DHT 22, AM2302, AM2321
//#define DHTTYPE DHT21   // DHT 21, AM2301

// initialize DHT
DHT dht(DHTPIN, DHTTYPE);

// WiFi
char ssid[] = "pcveskole"; // enter your wifi home router ssid
char password[] = "pcveskole" ; // enter your wifi home router ssid

// Thingspeak server
char server1[] = "api.thingspeak.com";
String apiWritekey = "Vas API klic - Thingspeak";
// TMEP server
char server2[] = "vase_subdomena.tmep.cz";
const char guid[] = "Vase GUID - TMEP";

float tempC;
float hum;
//int tmr;

// initialize WiFi
WiFiClient client;

void connect_wifi() {
  WiFi.disconnect();
  delay(10);
  Serial.print("Connecting to ");
  Serial.println(ssid);
  WiFi.begin(ssid, password);
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }
  Serial.println("");
  Serial.println(WiFi.localIP());
  Serial.print("Connected to wifi...");
}
 
void data_thingspeak() {
  //send datat to Thingspeak
  if (client.connect(server1,80))
  {  
    String Data = apiWritekey;
           Data +="&field1=";
           Data += String(tempC);
           Data +="&field2=";
           Data += String(hum);    
           Data += "\r\n\r\n";
 
     Serial.print(F("Requesting data: "));
     Serial.println(Data);
     client.print("POST /update HTTP/1.1\n");
     client.print("Host: api.thingspeak.com\n");
     client.print("Connection: close\n");
     client.print("X-THINGSPEAKAPIKEY: "+apiWritekey+"\n");
     client.print("Content-Type: application/x-www-form-urlencoded\n");
     client.print("Content-Length: ");
     client.print(Data.length());
     client.print("\n\n");  
     client.print(Data);
     Serial.println("uploaded to Thingspeak server....");
  }
  client.stop();
}

void data_tmep() {
  //send datat to tmep.cz
  if (client.connect(server2,80))
  {  
    // Make an url string. We need: /?guid=t
    String Data = "/?";
           Data +=guid;
           Data += "=";
           Data += String(tempC);
           Data += "&humV=";
           Data += String(hum);    
     
    Serial.print(F("Requesting URL: ")); Serial.println(Data);
     
    // Make a HTTP GET request.
    client.print(String("GET ") + Data + " HTTP/1.1\r\n" +
               "Host: " + server2 + "\r\n" + 
               "Connection: close\r\n\r\n");
    //
    Serial.println("uploaded to tmep.cz server....");
  }
  client.stop();
}

void setup() {
  // DHT11 sensor
  dht.begin();

  Serial.begin(9600);
  Serial.println("Initializing...");
  
  // connect wifi
  connect_wifi();      
}

void loop() {
  
  //tmr = millis()/1000;
  //  Serial.println(tmr);
  
  hum = dht.readHumidity();
  tempC = dht.readTemperature(); // or dht.readTemperature(true) for Fahrenheit
  
  if (isnan(hum) || isnan(tempC)) {
    Serial.println("Failed to read from DHT sensor!");
    return;
  } else {
     Serial.println("Actual data (temperature, humidity): "); 
     Serial.println(tempC);
     Serial.println(hum);
  }
     
  //send to Thingspeak
   //data_thingspeak();
  //send to tmep.cz
   data_tmep();
  
  //tmr = millis()/1000;
  //  Serial.println(tmr);
  
  // nyní musíme vyčkat minimálně 15 vteřin do dalšího odeslání dat,
  // 15 vteřin je omezení Thingspeaku, v tomto příkladu je nastaven
  // interval 60 vteřin
  Serial.println("Pauza pred dalsim odeslanim dat...");
  delay(60000);    
}