#define BLYNK_PRINT Serial

#include <ESP8266WiFi.h>
#include <BlynkSimpleEsp8266.h>
#include <DHT.h>

// You should get Auth Token in the Blynk App.
// Go to the Project Settings (nut icon).
char auth[] = "Your Auth Token";

// Your WiFi credentials.
// Set password to "" for open networks.
char ssid[] = "your ssid";
char pass[] = "your pass";

#define DHTPIN 2          // What digital pin we're connected to

// Uncomment whatever type you're using!
#define DHTTYPE DHT11     // DHT 11

DHT dht(DHTPIN, DHTTYPE);
BlynkTimer timer;

int LED_PIN = 5; //D1

ICACHE_RAM_ATTR void notifyOnButtonPress()
{
  // Invert state, since button is "Active LOW"
  int isButtonPressed = !digitalRead(D3);
  if (isButtonPressed) {
    Serial.println("Button is pressed.");

    // Note:
    //   We allow 1 notification per 5 seconds for now.
    //Blynk.notify("Yaaay... button is pressed!");

    // You can also use {DEVICE_NAME} placeholder for device name,
    // that will be replaced by your device name on the server side.
    //Blynk.notify("Na zařízení: {DEVICE_NAME}, bylo stisknuto tlačítko!");
    Blynk.notify("V kuchyni se podává jídlo. Kdo nepříjde, má smůlu!");
    Blynk.email("Blynk: Podava se jidlo", "V kuchyni se podává jídlo. Kdo nepříjde, má smůlu!");
  }
}

// This function will be called every Button Widget
// in Blynk app writes values to the Virtual Pin V9
BLYNK_WRITE(V9)
{
  //get value from virtual pin
  int pinValue = param.asInt(); // assigning incoming value from pin V9 to a variable
  
  // process received value
  if(pinValue == 1) {     // if Button sends 1
    digitalWrite(LED_PIN, HIGH);          // LED on
    Serial.println("LED on");
  } else {
    digitalWrite(LED_PIN, LOW);          // LED off 
    Serial.println("LED off");
  }
}

// This function sends Arduino's up time every second to Virtual Pin (5).
// In the app, Widget's reading frequency should be set to PUSH. This means
// that you define how often to send data to Blynk App.
void sendSensor()
{
  float h = dht.readHumidity();
  float t = dht.readTemperature(); // or dht.readTemperature(true) for Fahrenheit

  if (isnan(h) || isnan(t)) {
    Serial.println("Failed to read from DHT sensor!");
    return;
  }
  // You can send any value at any time.
  // Please don't send more that 10 values per second.
  Blynk.virtualWrite(V5, h);
  Blynk.virtualWrite(V6, t);
}

void setup()
{
  // Debug console
  Serial.begin(9600);
  
  pinMode(LED_PIN, OUTPUT);
  
  Blynk.begin(auth, ssid, pass);
  // You can also specify server:
  //Blynk.begin(auth, ssid, pass, "blynk-cloud.com", 80);
  //Blynk.begin(auth, ssid, pass, IPAddress(192,168,1,100), 8080);

  dht.begin();

  // Setup a function to be called every second
  timer.setInterval(5000L, sendSensor);
  
  // Setup notification button on pin 0 //D3
  pinMode(D3, INPUT_PULLUP);
  // Attach pin 0 (D3) interrupt to our handler
  attachInterrupt(digitalPinToInterrupt(D3), notifyOnButtonPress, CHANGE);
}

void loop()
{
  Blynk.run();
  timer.run();
}
